;; Generated package description from a68-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "a68-mode" "1.2.0.20260612.43" "Major mode for editing Algol 68 code" '((emacs "24.3")) :commit "aaebd2857a39a3c9600428e9a300fcd0a9371c1f" :authors '(("Omar Polo" . "op@omarpolo.com")) :maintainer '("Jose E. Marchesi" . "jemarch@gnu.org") :keywords '("languages") :url "https://git.sr.ht/~jemarch/a68-mode")
